@@ -28,6 +28,7 @@ import threading
 
 from vdsm.common import concurrent
 from vdsm.common import cpuarch
+from vdsm.storage import lvm
 
 from . config import config
 from . import metrics
@@ -38,8 +39,8 @@ _monitor = None
 def start():
     global _monitor
     assert _monitor is None
-    if config.getboolean("devel", "health_monitor_enable"):
-        interval = config.getint("devel", "health_check_interval")
+    if config.getboolean("health", "monitor_enable"):
+        interval = config.getint("health", "check_interval")
         _monitor = Monitor(interval)
         _monitor.start()
 
@@ -92,6 +93,7 @@ class Monitor(object):
         self.log.debug("Checking health")
         self._check_garbage()
         self._check_resources()
+        self._check_lvm_stats()
         self._report_stats()
 
     def _check_garbage(self):
@@ -123,6 +125,11 @@ class Monitor(object):
                        abs(delta_rss),
                        self._stats['threads'])
 
+    def _check_lvm_stats(self):
+        stats = lvm.cache_stats()
+        self.log.info("LVM cache hit ratio: %.2f%% (hits: %d misses: %d)",
+                      stats["hit_ratio"], stats["hits"], stats["misses"])
+
     def _report_stats(self):
         prefix = "hosts.vdsm"
         report = {}
