@@ -201,14 +201,6 @@ def cpu_features():
             for feature in mode.findall('feature'):
                 if feature.get('policy') == 'require':
                     features.append(feature.get('name'))
-            # Easier to add here than in Engine:
-            # If -IBRS suffix is present in the CPU model, we can assume
-            # spec_ctrl feature.
-            model = mode.find('model')
-            if model is not None and model.text.endswith('-IBRS'):
-                spec_ctrl = 'spec_ctrl'
-                if spec_ctrl not in features:
-                    features.append(spec_ctrl)
     logging.debug('CPU features: %s', features)
 
     return features
