@@ -24,7 +24,6 @@ import logging
 
 import six
 
-from vdsm.common.cache import memoized
 from vdsm.common.time import monotonic_time
 from vdsm.network import cmd
 from vdsm.network import connectivity
@@ -39,8 +38,6 @@ from vdsm.network.link import setup as link_setup
 from vdsm.network.link.iface import iface as iface_obj
 from vdsm.network.netconfpersistence import RunningConfig, Transaction
 from vdsm.network.netlink import waitfor
-from vdsm.network.ovs import info as ovs_info
-from vdsm.network.ovs import switch as ovs_switch
 from vdsm.network.link import bond
 from vdsm.network.netinfo import bridges
 from vdsm.network.netinfo.cache import get as netinfo_get, NetInfo
@@ -68,8 +65,6 @@ def validate(networks, bondings, net_info, running_config):
         )
 
     validator.validate_network_setup(networks, bondings, net_info)
-    if use_legacy_switch:
-        validator.validate_legacy_network_setup(legacy_nets)
 
 
 def setup(networks, bondings, options, in_rollback):
@@ -236,14 +231,6 @@ def _setup_ovs_bridge_mappings(running_networks, networks):
             )
 
 
-def ovs_add_vhostuser_port(bridge, port, socket_path):
-    ovs_switch.add_vhostuser_port(bridge, port, socket_path)
-
-
-def ovs_remove_port(bridge, port):
-    ovs_switch.remove_port(bridge, port)
-
-
 def netcaps(compatibility):
     net_caps = netinfo(compatibility=compatibility)
     _add_speed_device_info(net_caps)
@@ -255,10 +242,16 @@ def netinfo(vdsmnets=None, compatibility=None):
     # TODO: Version requests by engine to ease handling of compatibility.
     running_config = RunningConfig()
     _netinfo = netinfo_get(vdsmnets, compatibility)
-    if _is_ovs_service_running():
+
+    ovs_nets, _ = util.split_switch_type(
+        running_config.networks, running_config={}
+    )
+    ovs_bonds = util.split_switch_type(running_config.bonds, running_config={})
+    if ovs_nets or ovs_bonds:
         state = nmstate.state_show()
         nmstate.ovs_netinfo(_netinfo, running_config.networks, state)
-        _set_bond_type_by_usage(_netinfo)
+        _set_bond_type_by_usage(_netinfo, running_config.bonds)
+
     return _netinfo
 
 
@@ -292,7 +285,7 @@ def _add_bridge_opts(net_caps):
         bridgeattr['opts'] = bridges.bridge_options(bridgename)
 
 
-def _set_bond_type_by_usage(_netinfo):
+def _set_bond_type_by_usage(_netinfo, running_bonds):
     """
     Engine uses bond switch type to indicate what switch type implementation
     the bond belongs to (as each is implemented and managed differently).
@@ -301,24 +294,12 @@ def _set_bond_type_by_usage(_netinfo):
     examined against the running config for the switch that uses it and updates
     its switch type accordingly.
     """
-    for bond_name, bond_attrs in six.iteritems(RunningConfig().bonds):
+    for bond_name, bond_attrs in running_bonds.items():
         if (
-            bond_attrs['switch'] == ovs_switch.SWITCH_TYPE
+            bond_attrs['switch'] == util.SwitchType.OVS
             and bond_name in _netinfo['bondings']
         ):
-            _netinfo['bondings'][bond_name]['switch'] = ovs_switch.SWITCH_TYPE
-
-
-@memoized
-def _is_ovs_service_running():
-    return ovs_info.is_ovs_service_running()
-
-
-def ovs_net2bridge(network_name):
-    if not _is_ovs_service_running():
-        return None
-
-    return ovs_info.bridge_info(network_name)
+            _netinfo['bondings'][bond_name]['switch'] = util.SwitchType.OVS
 
 
 def net2northbound(network_name):
@@ -333,12 +314,6 @@ def net2northbound(network_name):
     return nb_device
 
 
-def net2vlan(network_name):
-    # Using RunningConfig avoids the need to require root access.
-    net_attr = RunningConfig().networks.get(network_name)
-    return net_attr.get('vlan') if net_attr else None
-
-
 def switch_type_change_needed(nets, bonds, running_config):
     """
     Check if we have to do switch type change in order to set up requested
