@@ -71,26 +71,31 @@ def requires_image_daemon(func):
 @requires_image_daemon
 def add_ticket(ticket):
     body = json.dumps(ticket)
-    request("PUT", ticket["uuid"], body)
+    _request("PUT", ticket["uuid"], body)
 
 
 @requires_image_daemon
 def get_ticket(ticket_id):
-    return request("GET", ticket_id)
+    response, content = _request("GET", ticket_id)
+    try:
+        return json.loads(content)
+    except ValueError as e:
+        error_info = {"explanation": "Invalid JSON", "detail": str(e)}
+        raise se.ImageDaemonError(response.status, response.reason, error_info)
 
 
 @requires_image_daemon
 def extend_ticket(uuid, timeout):
     body = json.dumps({"timeout": timeout})
-    request("PATCH", uuid, body)
+    _request("PATCH", uuid, body)
 
 
 @requires_image_daemon
 def remove_ticket(uuid):
-    request("DELETE", uuid)
+    _request("DELETE", uuid)
 
 
-def request(method, uuid, body=None):
+def _request(method, uuid, body=None):
     log.debug("Sending request method=%r, ticket=%r, body=%r",
               method, uuid, body)
     if body is not None:
@@ -107,8 +112,12 @@ def request(method, uuid, body=None):
 
         content = _read_content(res)
         if res.status >= 300:
-            raise se.ImageDaemonError(res.status, res.reason, content)
-        return content
+            try:
+                error = content.decode("utf8")
+            except (UnicodeDecodeError, LookupError):
+                error = repr(content)
+            raise se.ImageDaemonError(res.status, res.reason, error)
+        return res, content
 
 
 def _read_content(response):
@@ -116,20 +125,11 @@ def _read_content(response):
     # connections. HTTPResponse.read() is doing the right thing, handling
     # request content length or chunked encoding.
     try:
-        res_data = response.read()
+        # This can also be a "200 OK" with "Content-Length: 0",
+        # or "204 No Content" without Content-Length header.
+        # See https://tools.ietf.org/html/rfc7230#section-3.3.2
+        return response.read()
     except EnvironmentError as e:
         error_info = {"explanation": "Error reading response",
                       "detail": str(e)}
         raise se.ImageDaemonError(response.status, response.reason, error_info)
-
-    # This can be a "200 OK" with "Content-Length: 0", or "204 No Content"
-    # without Content-Length header.
-    # See https://tools.ietf.org/html/rfc7230#section-3.3.2
-    if not res_data:
-        return {}
-
-    try:
-        return json.loads(res_data.decode("utf8"))
-    except ValueError as e:
-        error_info = {"explanation": "Invalid JSON", "detail": str(e)}
-        raise se.ImageDaemonError(response.status, response.reason, error_info)
